@@ -5,9 +5,10 @@ use warnings;
 package Log::Any;
 
 # ABSTRACT: Bringing loggers and listeners together
-our $VERSION = '1.037'; # TRIAL
+our $VERSION = '1.041'; # TRIAL
 
 use Log::Any::Manager;
+use Log::Any::Proxy::Null;
 use Log::Any::Adapter::Util qw(
   require_dynamic
   detection_aliases
@@ -91,7 +92,8 @@ sub _get_proxy_class {
     my ( $self, $proxy_name ) = @_;
     return $Log::Any::OverrideDefaultProxyClass
       if $Log::Any::OverrideDefaultProxyClass;
-    return "Log::Any::Proxy" unless $proxy_name;
+    return "Log::Any::Proxy" if !$proxy_name && _manager->has_consumer;
+    return "Log::Any::Proxy::Null" if !$proxy_name;
     my $proxy_class = (
           substr( $proxy_name, 0, 1 ) eq '+'
         ? substr( $proxy_name, 1 )
@@ -120,7 +122,7 @@ Log::Any - Bringing loggers and listeners together
 
 =head1 VERSION
 
-version 1.037
+version 1.041
 
 =head1 SYNOPSIS
 
@@ -135,6 +137,9 @@ In a CPAN or other module:
     # log a string and data using a formatting filter
     $log->debugf("arguments are: %s", \@_);
 
+    # log an error and throw an exception
+    die $log->fatal("a fatal error occurred");
+
 In a Moo/Moose-based module:
 
     package Foo;
@@ -198,14 +203,6 @@ whether the application has chosen (or will ever choose) a logging mechanism.
 See L<http://www.openswartz.com/2007/09/06/standard-logging-api/> for the
 original post proposing this module.
 
-=head1 NAME
-
-Log::Any - Bringing loggers and listeners together
-
-=head1 VERSION
-
-version 1.037
-
 =head1 LOG LEVELS
 
 C<Log::Any> supports the following log levels and aliases, which is meant to be
@@ -274,6 +271,9 @@ To log a message, pass a single string to any of the log levels or aliases. e.g.
     $log->warn("this is a warning");
     $log->warning("this is also a warning");
 
+The log string will be returned so that it can be used further (e.g. for a C<die> or
+C<warn> call).
+
 You should B<not> include a newline in your message; that is the responsibility
 of the logging mechanism, which may or may not want the newline.
 
@@ -397,7 +397,7 @@ other niceties.
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests through the issue tracker
-at L<https://github.com/dagolden/Log-Any/issues>.
+at L<https://github.com/preaction/Log-Any/issues>.
 You will be notified automatically of any progress on your issue.
 
 =head2 Source Code
@@ -405,9 +405,9 @@ You will be notified automatically of any progress on your issue.
 This is open source software.  The code repository is available for
 public review and contribution under the terms of the license.
 
-L<https://github.com/dagolden/Log-Any>
+L<https://github.com/preaction/Log-Any>
 
-  git clone https://github.com/dagolden/Log-Any.git
+  git clone https://github.com/preaction/Log-Any.git
 
 =head1 AUTHORS
 
@@ -421,11 +421,15 @@ Jonathan Swartz <swartz@pobox.com>
 
 David Golden <dagolden@cpan.org>
 
+=item *
+
+Doug Bell <preaction@cpan.org>
+
 =back
 
 =head1 CONTRIBUTORS
 
-=for stopwords cm-perl David Golden Maxim Vuets Stephen Thirlwall
+=for stopwords cm-perl Lucas Kanashiro Maxim Vuets Stephen Thirlwall
 
 =over 4
 
@@ -435,7 +439,7 @@ cm-perl <cm-perl@users.noreply.github.com>
 
 =item *
 
-David Golden <xdg@xdg.me>
+Lucas Kanashiro <kanashiro.duarte@gmail.com>
 
 =item *
 
@@ -449,71 +453,7 @@ Stephen Thirlwall <sdt@dr.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Jonathan Swartz and David Golden.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
-
-=head1 SUPPORT
-
-=head2 Bugs / Feature Requests
-
-Please report any bugs or feature requests through the issue tracker
-at L<https://github.com/dagolden/Log-Any/issues>.
-You will be notified automatically of any progress on your issue.
-
-=head2 Source Code
-
-This is open source software.  The code repository is available for
-public review and contribution under the terms of the license.
-
-L<https://github.com/dagolden/Log-Any>
-
-  git clone https://github.com/dagolden/Log-Any.git
-
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-Jonathan Swartz <swartz@pobox.com>
-
-=item *
-
-David Golden <dagolden@cpan.org>
-
-=back
-
-=head1 CONTRIBUTORS
-
-=for stopwords cm-perl David Golden Maxim Vuets Stephen Thirlwall
-
-=over 4
-
-=item *
-
-cm-perl <cm-perl@users.noreply.github.com>
-
-=item *
-
-David Golden <xdg@xdg.me>
-
-=item *
-
-Maxim Vuets <maxim.vuets@booking.com>
-
-=item *
-
-Stephen Thirlwall <sdt@dr.com>
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2014 by Jonathan Swartz and David Golden.
+This software is copyright (c) 2016 by Jonathan Swartz, David Golden, and Doug Bell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
