@@ -5,7 +5,7 @@ use warnings;
 package Log::Any::Proxy;
 
 # ABSTRACT: Log::Any generator proxy object
-our $VERSION = '1.037'; # TRIAL
+our $VERSION = '1.041'; # TRIAL
 
 use Log::Any::Adapter::Util ();
 
@@ -18,6 +18,12 @@ sub _default_formatter {
           : ref($_)     ? Log::Any::Adapter::Util::dump_one_line($_)
           : $_
       } @params;
+    # Perl 5.22 adds a 'redundant' warning if the number parameters exceeds
+    # the number of sprintf placeholders.  If a user does this, the warning
+    # is issued from here, which isn't very helpful.  Doing something
+    # clever would be expensive, so instead we just disable warnings for
+    # the final line of this subroutine.
+    no warnings;
     return sprintf( $format, @new_params );
 }
 
@@ -62,13 +68,16 @@ foreach my $name ( Log::Any::Adapter::Util::logging_methods(), keys(%aliases) )
     *{$name} = sub {
         my ( $self, @parts ) = @_;
         my $message = join(" ", grep { defined($_) && length($_) } @parts );
-        return unless length $message;
-        $message = $self->{filter}->( $self->{category}, $numeric, $message )
-          if defined $self->{filter};
-        return unless defined $message and length $message;
-        $message = "$self->{prefix}$message"
-          if defined $self->{prefix} && length $self->{prefix};
-        return $self->{adapter}->$realname($message);
+        if ( length $message ) {
+            $message = $self->{filter}->( $self->{category}, $numeric, $message )
+              if defined $self->{filter};
+            if ( defined $message and length $message ) {
+                $message = "$self->{prefix}$message"
+                  if defined $self->{prefix} && length $self->{prefix};
+                $self->{adapter}->$realname($message);
+            }
+        }
+        return $message if defined wantarray;
     };
     *{$namef} = sub {
         my ( $self, @args ) = @_;
@@ -97,7 +106,7 @@ Log::Any::Proxy - Log::Any generator proxy object
 
 =head1 VERSION
 
-version 1.037
+version 1.041
 
 =head1 SYNOPSIS
 
@@ -170,8 +179,8 @@ Pass a string to be logged.  Do not include a newline.
 
     $log->info("Got some new for you.");
 
-The log string will be tranformed via the C<filter> attribute (if any) and
-the C<prefix> (if any) will be prepended.
+The log string will be transformed via the C<filter> attribute (if any) and
+the C<prefix> (if any) will be prepended. Returns the transformed log string.
 
 B<NOTE>: While you are encouraged to pass a single string to be logged, if
 multiple arguments are passed, they are concatenated with a space character
@@ -237,15 +246,8 @@ message. Otherwise, the formatter acts like C<sprintf> with some helpful
 formatting.
 
 Finally, the message string is logged via the simple logging functions,
-which can transform or prefix as described above.
-
-=head1 NAME
-
-Log::Any::Proxy - Log::Any generator proxy object
-
-=head1 VERSION
-
-version 1.037
+which can transform or prefix as described above. The transformed log
+string is then returned.
 
 =head1 ATTRIBUTES
 
@@ -325,32 +327,15 @@ Jonathan Swartz <swartz@pobox.com>
 
 David Golden <dagolden@cpan.org>
 
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2014 by Jonathan Swartz and David Golden.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=head1 AUTHORS
-
-=over 4
-
 =item *
 
-Jonathan Swartz <swartz@pobox.com>
-
-=item *
-
-David Golden <dagolden@cpan.org>
+Doug Bell <preaction@cpan.org>
 
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Jonathan Swartz and David Golden.
+This software is copyright (c) 2016 by Jonathan Swartz, David Golden, and Doug Bell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
