@@ -5,7 +5,7 @@ use warnings;
 package Log::Any::Test;
 
 # ABSTRACT: Test what you're logging with Log::Any
-our $VERSION = '1.037'; # TRIAL
+our $VERSION = '1.041'; # TRIAL
 
 no warnings 'once';
 $Log::Any::OverrideDefaultAdapterClass = 'Log::Any::Adapter::Test';
@@ -25,7 +25,7 @@ Log::Any::Test - Test what you're logging with Log::Any
 
 =head1 VERSION
 
-version 1.037
+version 1.041
 
 =head1 SYNOPSIS
 
@@ -54,16 +54,12 @@ C<Log::Any::Test> is a simple module that allows you to test what has been
 logged with Log::Any. Most of its API and implementation have been taken from
 L<Log::Any::Dispatch|Log::Any::Dispatch>.
 
-Using C<Log::Any::Test> sends all subsequent Log::Any log messages to a single
-global in-memory buffer.  It should be used before L<Log::Any|Log::Any>.
-
-=head1 NAME
-
-Log::Any::Test - Test what you're logging with Log::Any
-
-=head1 VERSION
-
-version 1.037
+Using C<Log::Any::Test> signals C<Log::Any> to send all subsequent log
+messages to a single global in-memory buffer and to make the log proxy
+provide a number of testing functions.  To use it, load C<Log::Any::Test>
+before anything that loads C<Log::Any>.  To actually use the test methods,
+you need to load C<Log::Any> and get a log object from it, as shown in the
+L</SYNOPSIS>.
 
 =head1 METHODS
 
@@ -142,32 +138,15 @@ Jonathan Swartz <swartz@pobox.com>
 
 David Golden <dagolden@cpan.org>
 
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2014 by Jonathan Swartz and David Golden.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=head1 AUTHORS
-
-=over 4
-
 =item *
 
-Jonathan Swartz <swartz@pobox.com>
-
-=item *
-
-David Golden <dagolden@cpan.org>
+Doug Bell <preaction@cpan.org>
 
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Jonathan Swartz and David Golden.
+This software is copyright (c) 2016 by Jonathan Swartz, David Golden, and Doug Bell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
